/* INCLUDE per lettura file in formato BMP */
/* VER$ 1.00 05/11/97			   */
/*******************************************/

typedef struct tagBITMAPFILEHEADER {    /* bmfh */
    UWORD   bfType;
    ULONG   bfSize;
    UWORD   bfReserved1;
    UWORD   bfReserved2;
    ULONG   bfOffBits;
} BITMAPFILEHEADER;

/*
Member          Description

bfType          Specifies the type of file. This member must be BM.
bfSize          Specifies the size of the file, in bytes.
bfReserved1     Reserved; must be set to zero.
bfReserved2     Reserved; must be set to zero.
bfOffBits       Specifies the byte offset from the BITMAPFILEHEADER structure
		to the actual bitmap data in the file.
*/

typedef struct tagBITMAPINFOHEADER {    /* bmih */
    ULONG   biSize;
    ULONG   biWidth;
    ULONG   biHeight;
    UWORD   biPlanes;
    UWORD   biBitCount;
    ULONG   biCompression;
    ULONG   biSizeImage;
    ULONG   biXPelsPerMeter;
    ULONG   biYPelsPerMeter;
    ULONG   biClrUsed;
    ULONG   biClrImportant;
} BITMAPINFOHEADER;

/*
Member          Description

biSize          Specifies the number of bytes required by the
BITMAPINFOHEADER structure.

biWidth         Specifies the width of the bitmap, in pixels.
biHeightSpecifies the height of the bitmap, in pixels.

biPlanesSpecifies the number of planes for the target device. This
member must be set to 1.

biBitCount      Specifies the number of bits per pixel. This value must be 1,
4, 8, or 24.

biCompression   Specifies the type of compression for a compressed bitmap. It
can be one of the following values:

Value           Meaning

BI_RGB          Specifies that the bitmap is not compressed.

BI_RLE8         Specifies a run-length encoded format for bitmaps with 8 bits
per pixel. The compression format is a 2-byte format consisting of a count
byte followed by a byte containing a color index.  For more information, see
the following Comments section.

BI_RLE4         Specifies a run-length encoded format for bitmaps with 4 bits
per pixel. The compression format is a 2-byte format consisting of a count
byte followed by two word-length color indexes.  For more information, see
the following Comments section.

biSizeImage     Specifies the size, in bytes, of the image. It is valid to
set this member to zero if the bitmap is in the BI_RGB format.

biXPelsPerMeter Specifies the horizontal resolution, in pixels per meter, of
the target device for the bitmap. An application can use this value to select
a bitmap from a resource group that best matches the characteristics of the
current device.

biYPelsPerMeter Specifies the vertical resolution, in pixels per meter, of
the target device for the bitmap.

biClrUsed       Specifies the number of color indexes in the color table
actually used by the bitmap. If this value is zero, the bitmap uses the
maximum number of colors corresponding to the value of the biBitCount member.
For more information on the maximum sizes of the color table, see the
description of the BITMAPINFO structure earlier in this topic.

If the biClrUsed member is nonzero, it specifies the actual number of colors
that the graphics engine or device driver will access if the biBitCount
member is less than 24. If biBitCount is set to 24, biClrUsed specifies the
size of the reference color table used to optimize performance of Windows
color palettes.  If the bitmap is a packed bitmap (that is, a bitmap in which
the bitmap array immediately follows the BITMAPINFO header and which is
referenced by a single pointer), the biClrUsed member must be set to zero or
to the actual size of the color table.

biClrImportant  Specifies the number of color indexes that are considered
important for displaying the bitmap. If this value is zero, all colors are
important.
*/

typedef struct tagRGBQUAD {     /* rgbq */
    UBYTE    rgbBlue;
    UBYTE    rgbGreen;
    UBYTE    rgbRed;
    UBYTE    rgbReserved;
} RGBQUAD;

/*
Member          Description

rgbBlue         Specifies the intensity of blue in the color.
rgbGreenSpecifies the intensity of green in the color.
rgbRed          Specifies the intensity of red in the color.
rgbReserved     Not used; must be set to zero.
*/

typedef struct tagBITMAPINFO {  /* bmi */
    BITMAPINFOHEADER    bmiHeader;
    RGBQUAD             bmiColors[1];
} BITMAPINFO;

/*
Member          Description

bmiHeader       Specifies a BITMAPINFOHEADER structure that contains
		information about the dimensions and color format of a DIB.

bmiColors       Specifies an array of RGBQUAD structures that define the
		colors in the bitmap.
*/


//COLORREF RGB(cRed, cGreen, cBlue)

//UBYTE cRed;      /* red component of color       */
//UBYTE cGreen;    /* green component of color     */
//UBYTE cBlue;     /* blue component of color      */

//Parameter       Description

//cRed    Specifies the intensity of the red color field.
//cGreen  Specifies the intensity of the green color field.
//cBlue   Specifies the intensity of the blue color field.

//Returns

//The return value specifies the resultant RGB color.


#define RGB(r,g,b)   ((COLORREF)(((UBYTE)(r)|((UWORD)(g)<<8))| \
    (((ULONG)(UBYTE)(b))<<16)))

typedef struct tagBITMAPCOREHEADER {    /* bmch */
    ULONG   bcSize;
    short   bcWidth;
    short   bcHeight;
    UWORD   bcPlanes;
    UWORD   bcBitCount;
} BITMAPCOREHEADER;

/*
Member          Description

bcSize          Specifies the number of bytes required by the
BITMAPCOREHEADER structure.

bcWidth         Specifies the width of the bitmap, in pixels.
bcHeightSpecifies the height of the bitmap, in pixels.

bcPlanesSpecifies the number of planes for the target device. This
member must be set to 1.

bcBitCount      Specifies the number of bits per pixel. This value must be 1,
4, 8, or 24.
*/

/*************************************************************************/
//An application should use the information stored in the bcSize member to
//locate the color table in a BITMAPCOREINFO structure with a method such as
//the following:
//lpColor = ((LPSTR) pBitmapCoreInfo + (UINT) (pBitmapCoreInfo->bcSize))
/*************************************************************************/

typedef struct tagRGBTRIPLE {   /* rgbt */
    UBYTE    rgbtBlue;
    UBYTE    rgbtGreen;
    UBYTE    rgbtRed;
} RGBTRIPLE;

/*
Member  Description

rgbtBlueSpecifies the intensity of blue in the color.
rgbtGreen       Specifies the intensity of green in the color.
rgbtRed         Specifies the intensity of red in the color.
*/

typedef struct tagBITMAPCOREINFO {  /* bmci */
    BITMAPCOREHEADER bmciHeader;
    RGBTRIPLE        bmciColors[1];
} BITMAPCOREINFO;

/*
Member          Description

bmciHeader      Specifies a BITMAPCOREHEADER structure that contains
information about the dimensions and color format of a DIB.

bmciColors      Specifies an array of RGBTRIPLE structures that define the
colors in the bitmap.
*/

